@@ -9,6 +9,15 @@ DEST = '../../usr/share/themes'
 
 curdir = os.getcwd()
 
+print("Updating Gtk4 assets")
+os.chdir("gtk-4.0/")
+os.system("sassc ./sass/gtk.scss gtk.css")
+os.system("sassc ./sass/gtk-dark.scss gtk-dark.css")
+os.system("./render-assets.sh")
+print("Gtk4 assets updated")
+
+os.chdir(curdir)
+
 print("Updating Gtk3 assets")
 os.chdir("gtk-3.0/")
 os.system("sassc ./sass/gtk.scss gtk.css")
@@ -67,6 +76,12 @@ if __name__ == '__main__':
             os.system("cp gtk-3.0/gtk.css %s" % version_folder)
             os.system("cp gtk-3.0/gtk-dark.css %s" % version_folder)
             os.system("cp gtk-3.0/thumbnail.png %s" % version_folder)
+            # Gtk4
+            version_folder = os.path.join(dest_folder, "gtk-4.0")
+            os.system("mkdir -p %s" % version_folder)
+            os.system("cp -R gtk-4.0/assets %s" % version_folder)
+            os.system("cp gtk-4.0/gtk.css %s" % version_folder)
+            os.system("cp gtk-4.0/gtk-dark.css %s" % version_folder)
             # Metacity
             os.system("cp -R metacity-1 %s" % dest_folder)
             # Cinnamon
@@ -100,6 +115,11 @@ if __name__ == '__main__':
             os.system("cp -R gtk-3.0/assets %s" % version_folder)
             os.system("cp gtk-3.0/gtk-dark.css %s" % os.path.join(version_folder, "gtk.css"))
             os.system("cp gtk-3.0/thumbnail-dark.png %s" % os.path.join(version_folder, "thumbnail.png"))
+            # Gtk4
+            version_folder = os.path.join(dest_folder, "gtk-4.0")
+            os.system("mkdir -p %s" % version_folder)
+            os.system("cp -R gtk-4.0/assets %s" % version_folder)
+            os.system("cp gtk-4.0/gtk-dark.css %s" % os.path.join(version_folder, "gtk.css"))
             # Cinnamon
             version_folder = os.path.join(dest_folder, "cinnamon")
             os.system("mkdir -p %s" % version_folder)
