@@ -2,8 +2,8 @@
 import os
 import sys
 
-from constants import Y_HEX_ACCENT1, Y_HEX_ACCENT2, Y_HEX_ACCENT3, Y_HEX_ACCENT4
-from constants import y_hex_colors1, y_hex_colors2, y_hex_colors3, y_hex_colors4
+from constants import Y_HEX_ACCENT1, Y_HEX_ACCENT2
+from constants import y_hex_colors1, y_hex_colors2
 
 def change_value (key, value, file):
     if value is not None:
@@ -23,6 +23,7 @@ def update_color (color):
     os.system("rm -rf %s" % variation)
     os.system("mkdir -p %s/gtk-2.0" % variation)
     os.system("mkdir -p %s/gtk-3.0" % variation)
+    os.system("mkdir -p %s/gtk-4.0" % variation)
     os.system("mkdir -p %s/xfwm4" % variation)
     os.system("mkdir -p %s/xfwm4-dark" % variation)
 
@@ -31,6 +32,7 @@ def update_color (color):
     assets.append("gtk-2.0/assets.svg")
     assets.append("gtk-2.0/assets-dark.svg")
     assets.append("gtk-3.0/assets.svg")
+    assets.append("gtk-4.0/assets.svg")
     assets.append("xfwm4/assets.svg")
     assets.append("xfwm4-dark/assets.svg")
 
@@ -43,6 +45,9 @@ def update_color (color):
     files.append("gtk-3.0/assets")
     files.append("gtk-3.0/assets.txt")
     files.append("gtk-3.0/render-assets.sh")
+    files.append("gtk-4.0/assets")
+    files.append("gtk-4.0/assets.txt")
+    files.append("gtk-4.0/render-assets.sh")
     files.append("xfwm4/render-assets.sh")
     files.append("xfwm4/assets.txt")
     files.append("xfwm4-dark/render-assets.sh")
@@ -60,10 +65,6 @@ def update_color (color):
             os.system("sed -i s'/%(accent)s/%(color_accent)s/gI' %(file)s" % {'accent': accent, 'color_accent': y_hex_colors1[color], 'file': asset_path})
         for accent in Y_HEX_ACCENT2:
             os.system("sed -i s'/%(accent)s/%(color_accent)s/gI' %(file)s" % {'accent': accent, 'color_accent': y_hex_colors2[color], 'file': asset_path})
-        for accent in Y_HEX_ACCENT3:
-            os.system("sed -i s'/%(accent)s/%(color_accent)s/gI' %(file)s" % {'accent': accent, 'color_accent': y_hex_colors3[color], 'file': asset_path})
-        for accent in Y_HEX_ACCENT4:
-            os.system("sed -i s'/%(accent)s/%(color_accent)s/gI' %(file)s" % {'accent': accent, 'color_accent': y_hex_colors4[color], 'file': asset_path})
 
     # Render assets
     os.chdir(variation)
@@ -75,6 +76,9 @@ def update_color (color):
     os.chdir("../gtk-3.0/")
     os.system("rm -rf assets/*")
     os.system("./render-assets.sh")
+    os.chdir("../gtk-4.0/")
+    os.system("rm -rf assets/*")
+    os.system("./render-assets.sh")
     os.chdir("../xfwm4/")
     os.system("rm -rf *.png")
     os.system("./render-assets.sh")
